MethodChannelIosColorPicker class
An implementation of IosColorPickerV2Platform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- IosColorPickerPlatform
- MethodChannelIosColorPicker
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformColor(
Map< String, double> ? defaultColor, bool? darkMode, String? title) → Future<Color?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited