IosColorPickerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IosColorPickerPlatform
Implementers

Constructors

IosColorPickerPlatform()
Constructs a IosColorPickerV2Platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformColor(Map<String, double>? defaultColor, bool? darkMode, String? title) Future<Color?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance IosColorPickerPlatform
The default instance of IosColorPickerV2Platform to use.
getter/setter pair