IosColorPickerWeb class
A web implementation of the IosColorPickerPlatform of the IosColorPicker plugin.
- Inheritance
-
- Object
- PlatformInterface
- IosColorPickerPlatform
- IosColorPickerWeb
Constructors
- IosColorPickerWeb()
- Constructs a IosColorPickerWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformColor(
Map< String, double> ? defaultColor, bool? darkMode, String? title) → Future<Color?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void