IOSColorPickerController class

Don't forget to Dispose the controller

because the streamer, check the example in example/ folder

Constructors

IOSColorPickerController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color
getter/setter pair

Methods

cancelColorSubscription() → void
Cancel the color subscription
dispose() → void
Dispose resources
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showIOSCustomColorPicker({required BuildContext context, required ValueChanged<Color> onColorChanged, Color? startingColor}) → void
iOS Native color Picker clone, for all Platforms.
showNativeIosColorPicker({required ValueChanged<Color> onColorChanged, Color? startingColor, bool? darkMode, String? title}) Future<void>
iOS Native color Picker, Only for iOS.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited