CacheHelper class
Local Data Helper
Constructors
- CacheHelper()
-
Factory constructor to return the singleton instance
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllData(
) → Future< bool> - Clear all data
-
clearData(
{required String key}) → Future< bool> - Clear specific data
-
getData(
{required String key}) → dynamic - Get data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setData<
T> ({required String key, required T value}) → Future< bool> - Save data
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited